diff --git a/.gitignore b/.gitignore
index 3e759b7..537eaeb 100644
--- a/.gitignore
+++ b/.gitignore
@@ -84,6 +84,8 @@ StyleCopReport.xml
*.pidb
*.svclog
*.scc
+*.dll
+*.exe
# Chutzpah Test files
_Chutzpah*
diff --git a/Capnp.Net.Runtime/Capnp.Net.Runtime.Std20.xml b/Capnp.Net.Runtime/Capnp.Net.Runtime.Std20.xml
index ee19157..d2e4c79 100644
--- a/Capnp.Net.Runtime/Capnp.Net.Runtime.Std20.xml
+++ b/Capnp.Net.Runtime/Capnp.Net.Runtime.Std20.xml
@@ -540,7 +540,7 @@
The end of the stream is reached.
The stream is closed.
An I/O error occurs.
- Encountered invalid framing data.
+ Encountered invalid framing data, too many or too large segments
Too many or too large segments, probably due to invalid framing data.
diff --git a/capnpc-csharp/Program.cs b/capnpc-csharp/Program.cs
index 779049a..4da2ad2 100644
--- a/capnpc-csharp/Program.cs
+++ b/capnpc-csharp/Program.cs
@@ -1,8 +1,6 @@
using Capnp;
using System;
using System.IO;
-using System.Linq;
-using System.Runtime.InteropServices;
namespace CapnpC
{
@@ -17,22 +15,33 @@ namespace CapnpC
input = new FileStream(args[0], FileMode.Open, FileAccess.Read);
}
else
- {
+ {
+ Console.WriteLine("Cap'n Proto C# code generator backend");
+ Console.WriteLine("expecting binary-encoded code generation request from standard input");
+
input = Console.OpenStandardInput();
}
- WireFrame segments;
-
- using (input)
+ try
{
- segments = Framing.ReadSegments(input);
- }
+ WireFrame segments;
- var dec = DeserializerState.CreateRoot(segments);
- var reader = Schema.CodeGeneratorRequest.Reader.Create(dec);
- var model = Model.SchemaModel.Create(reader);
- var codeGen = new Generator.CodeGenerator(model, new Generator.GeneratorOptions());
- codeGen.Generate();
+ using (input)
+ {
+ segments = Framing.ReadSegments(input);
+ }
+
+ var dec = DeserializerState.CreateRoot(segments);
+ var reader = Schema.CodeGeneratorRequest.Reader.Create(dec);
+ var model = Model.SchemaModel.Create(reader);
+ var codeGen = new Generator.CodeGenerator(model, new Generator.GeneratorOptions());
+ codeGen.Generate();
+ }
+ catch (Exception exception)
+ {
+ Console.Error.WriteLine(exception.Message);
+ Environment.ExitCode = -1;
+ }
}
}
}
diff --git a/capnpc-csharp/capnpc-csharp.csproj b/capnpc-csharp/capnpc-csharp.csproj
index 76ee9e5..4646c6c 100644
--- a/capnpc-csharp/capnpc-csharp.csproj
+++ b/capnpc-csharp/capnpc-csharp.csproj
@@ -1,10 +1,18 @@
-
+
Exe
netcoreapp2.1
CapnpC
7.1
+ false
+ MIT
+ Christian Köllner and contributors
+ Cap'n Proto C# code generator backend
+ Christian Köllner and contributors
+ https://github.com/c80k/capnproto-dotnetcore
+ Git
+ capnp capnpc RPC serialization cerealization
diff --git a/chocolatey/capnpc-csharp.1.0.0.nuspec b/chocolatey/capnpc-csharp.1.0.0.nuspec
new file mode 100644
index 0000000..85d6cfd
--- /dev/null
+++ b/chocolatey/capnpc-csharp.1.0.0.nuspec
@@ -0,0 +1,22 @@
+
+
+
+ capnpc-csharp
+ 1.0.0
+ Christian Köllner and contributors
+ Christian Köllner and contributors
+ false
+
+ https://licenses.nuget.org/MIT
+ https://github.com/c80k/capnproto-dotnetcore
+ Cap'n Proto C# code generator backend
+ Christian Köllner and contributors
+ capnp capnpc RPC serialization cerealization
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/chocolatey/chocolateyinstall.ps1 b/chocolatey/chocolateyinstall.ps1
new file mode 100644
index 0000000..025b147
--- /dev/null
+++ b/chocolatey/chocolateyinstall.ps1
@@ -0,0 +1,5 @@
+$ErrorActionPreference = 'Stop'
+
+$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
+
+Install-Binfile -Name capnpc-csharp -Path "$toolsDir\capnpc-csharp.exe"
diff --git a/chocolatey/chocolateyuninstall.ps1 b/chocolatey/chocolateyuninstall.ps1
new file mode 100644
index 0000000..e327e42
--- /dev/null
+++ b/chocolatey/chocolateyuninstall.ps1
@@ -0,0 +1,3 @@
+$ErrorActionPreference = 'Stop'
+
+Uninstall-BinFile capnpc-sharp
\ No newline at end of file
diff --git a/chocolatey/deploy/capnpc-csharp.deps.json b/chocolatey/deploy/capnpc-csharp.deps.json
new file mode 100644
index 0000000..477ed25
--- /dev/null
+++ b/chocolatey/deploy/capnpc-csharp.deps.json
@@ -0,0 +1,2464 @@
+{
+ "runtimeTarget": {
+ "name": ".NETCoreApp,Version=v2.1/win-x86",
+ "signature": "6a07f9ddd438cc6712001c4323ccce0127f8888f"
+ },
+ "compilationOptions": {},
+ "targets": {
+ ".NETCoreApp,Version=v2.1": {},
+ ".NETCoreApp,Version=v2.1/win-x86": {
+ "capnpc-csharp/1.0.0": {
+ "dependencies": {
+ "Capnp.Net.Runtime": "1.0.0",
+ "Microsoft.CodeAnalysis.CSharp": "2.10.0",
+ "Microsoft.Extensions.Logging": "2.2.0",
+ "Microsoft.NETCore.App": "2.1.12"
+ },
+ "runtime": {
+ "capnpc-csharp.dll": {}
+ }
+ },
+ "Microsoft.CodeAnalysis.Analyzers/2.6.1": {},
+ "Microsoft.CodeAnalysis.Common/2.10.0": {
+ "dependencies": {
+ "Microsoft.CodeAnalysis.Analyzers": "2.6.1",
+ "System.AppContext": "4.3.0",
+ "System.Collections": "4.3.0",
+ "System.Collections.Concurrent": "4.3.0",
+ "System.Collections.Immutable": "1.5.0",
+ "System.Console": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Diagnostics.FileVersionInfo": "4.3.0",
+ "System.Diagnostics.StackTrace": "4.3.0",
+ "System.Diagnostics.Tools": "4.3.0",
+ "System.Dynamic.Runtime": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO.Compression": "4.3.0",
+ "System.IO.FileSystem": "4.3.0",
+ "System.IO.FileSystem.Primitives": "4.3.0",
+ "System.Linq": "4.3.0",
+ "System.Linq.Expressions": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Metadata": "1.6.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Runtime.Numerics": "4.3.0",
+ "System.Security.Cryptography.Algorithms": "4.3.0",
+ "System.Security.Cryptography.Encoding": "4.3.0",
+ "System.Security.Cryptography.X509Certificates": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Text.Encoding.CodePages": "4.3.0",
+ "System.Text.Encoding.Extensions": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Threading.Tasks": "4.3.0",
+ "System.Threading.Tasks.Extensions": "4.3.0",
+ "System.Threading.Tasks.Parallel": "4.3.0",
+ "System.Threading.Thread": "4.3.0",
+ "System.ValueTuple": "4.3.0",
+ "System.Xml.ReaderWriter": "4.3.0",
+ "System.Xml.XDocument": "4.3.0",
+ "System.Xml.XPath.XDocument": "4.3.0",
+ "System.Xml.XmlDocument": "4.3.0"
+ },
+ "runtime": {
+ "lib/netstandard1.3/Microsoft.CodeAnalysis.dll": {
+ "assemblyVersion": "2.10.0.0",
+ "fileVersion": "2.10.0.0"
+ }
+ },
+ "resources": {
+ "lib/netstandard1.3/cs/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "cs"
+ },
+ "lib/netstandard1.3/de/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "de"
+ },
+ "lib/netstandard1.3/es/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "es"
+ },
+ "lib/netstandard1.3/fr/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "fr"
+ },
+ "lib/netstandard1.3/it/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "it"
+ },
+ "lib/netstandard1.3/ja/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "ja"
+ },
+ "lib/netstandard1.3/ko/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "ko"
+ },
+ "lib/netstandard1.3/pl/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "pl"
+ },
+ "lib/netstandard1.3/pt-BR/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "pt-BR"
+ },
+ "lib/netstandard1.3/ru/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "ru"
+ },
+ "lib/netstandard1.3/tr/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "tr"
+ },
+ "lib/netstandard1.3/zh-Hans/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "zh-Hans"
+ },
+ "lib/netstandard1.3/zh-Hant/Microsoft.CodeAnalysis.resources.dll": {
+ "locale": "zh-Hant"
+ }
+ }
+ },
+ "Microsoft.CodeAnalysis.CSharp/2.10.0": {
+ "dependencies": {
+ "Microsoft.CodeAnalysis.Common": "2.10.0"
+ },
+ "runtime": {
+ "lib/netstandard1.3/Microsoft.CodeAnalysis.CSharp.dll": {
+ "assemblyVersion": "2.10.0.0",
+ "fileVersion": "2.10.0.0"
+ }
+ },
+ "resources": {
+ "lib/netstandard1.3/cs/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "cs"
+ },
+ "lib/netstandard1.3/de/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "de"
+ },
+ "lib/netstandard1.3/es/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "es"
+ },
+ "lib/netstandard1.3/fr/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "fr"
+ },
+ "lib/netstandard1.3/it/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "it"
+ },
+ "lib/netstandard1.3/ja/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "ja"
+ },
+ "lib/netstandard1.3/ko/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "ko"
+ },
+ "lib/netstandard1.3/pl/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "pl"
+ },
+ "lib/netstandard1.3/pt-BR/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "pt-BR"
+ },
+ "lib/netstandard1.3/ru/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "ru"
+ },
+ "lib/netstandard1.3/tr/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "tr"
+ },
+ "lib/netstandard1.3/zh-Hans/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "zh-Hans"
+ },
+ "lib/netstandard1.3/zh-Hant/Microsoft.CodeAnalysis.CSharp.resources.dll": {
+ "locale": "zh-Hant"
+ }
+ }
+ },
+ "Microsoft.Extensions.Configuration/2.2.0": {
+ "dependencies": {
+ "Microsoft.Extensions.Configuration.Abstractions": "2.2.0"
+ },
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Configuration.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.Configuration.Abstractions/2.2.0": {
+ "dependencies": {
+ "Microsoft.Extensions.Primitives": "2.2.0"
+ },
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Configuration.Abstractions.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.Configuration.Binder/2.2.0": {
+ "dependencies": {
+ "Microsoft.Extensions.Configuration": "2.2.0"
+ },
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Configuration.Binder.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.DependencyInjection.Abstractions/2.2.0": {
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.DependencyInjection.Abstractions.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.Logging/2.2.0": {
+ "dependencies": {
+ "Microsoft.Extensions.Configuration.Binder": "2.2.0",
+ "Microsoft.Extensions.DependencyInjection.Abstractions": "2.2.0",
+ "Microsoft.Extensions.Logging.Abstractions": "2.2.0",
+ "Microsoft.Extensions.Options": "2.2.0"
+ },
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Logging.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.Logging.Abstractions/2.2.0": {
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Logging.Abstractions.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.Options/2.2.0": {
+ "dependencies": {
+ "Microsoft.Extensions.DependencyInjection.Abstractions": "2.2.0",
+ "Microsoft.Extensions.Primitives": "2.2.0",
+ "System.ComponentModel.Annotations": "4.5.0"
+ },
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Options.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.Extensions.Primitives/2.2.0": {
+ "dependencies": {
+ "System.Memory": "4.5.1",
+ "System.Runtime.CompilerServices.Unsafe": "4.5.1"
+ },
+ "runtime": {
+ "lib/netstandard2.0/Microsoft.Extensions.Primitives.dll": {
+ "assemblyVersion": "2.2.0.0",
+ "fileVersion": "2.2.0.18315"
+ }
+ }
+ },
+ "Microsoft.NETCore.App/2.1.12": {
+ "dependencies": {
+ "Microsoft.NETCore.DotNetHostPolicy": "2.1.12",
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "NETStandard.Library": "2.0.3",
+ "runtime.win-x86.Microsoft.NETCore.App": "2.1.12"
+ }
+ },
+ "Microsoft.NETCore.DotNetAppHost/2.1.12": {
+ "dependencies": {
+ "runtime.win-x86.Microsoft.NETCore.DotNetAppHost": "2.1.12"
+ }
+ },
+ "Microsoft.NETCore.DotNetHostPolicy/2.1.12": {
+ "dependencies": {
+ "Microsoft.NETCore.DotNetHostResolver": "2.1.12",
+ "runtime.win-x86.Microsoft.NETCore.DotNetHostPolicy": "2.1.12"
+ }
+ },
+ "Microsoft.NETCore.DotNetHostResolver/2.1.12": {
+ "dependencies": {
+ "Microsoft.NETCore.DotNetAppHost": "2.1.12",
+ "runtime.win-x86.Microsoft.NETCore.DotNetHostResolver": "2.1.12"
+ }
+ },
+ "Microsoft.NETCore.Platforms/2.1.5": {},
+ "Microsoft.NETCore.Targets/2.0.0": {},
+ "NETStandard.Library/2.0.3": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5"
+ }
+ },
+ "runtime.debian.8-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.fedora.23-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.fedora.24-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.native.System/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0"
+ }
+ },
+ "runtime.native.System.IO.Compression/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0"
+ }
+ },
+ "runtime.native.System.Net.Http/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0"
+ }
+ },
+ "runtime.native.System.Security.Cryptography.Apple/4.3.0": {
+ "dependencies": {
+ "runtime.osx.10.10-x64.runtime.native.System.Security.Cryptography.Apple": "4.3.0"
+ }
+ },
+ "runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "dependencies": {
+ "runtime.debian.8-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.fedora.23-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.fedora.24-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.opensuse.13.2-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.opensuse.42.1-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.osx.10.10-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.rhel.7-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.ubuntu.14.04-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.ubuntu.16.04-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0",
+ "runtime.ubuntu.16.10-x64.runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0"
+ }
+ },
+ "runtime.opensuse.13.2-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.opensuse.42.1-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.osx.10.10-x64.runtime.native.System.Security.Cryptography.Apple/4.3.0": {},
+ "runtime.osx.10.10-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.rhel.7-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.ubuntu.14.04-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.ubuntu.16.04-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.ubuntu.16.10-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {},
+ "runtime.win-x86.Microsoft.NETCore.App/2.1.12": {
+ "runtime": {
+ "runtimes/win-x86/lib/netcoreapp2.1/Microsoft.CSharp.dll": {
+ "assemblyVersion": "4.0.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/Microsoft.VisualBasic.dll": {
+ "assemblyVersion": "10.0.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/Microsoft.Win32.Primitives.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/Microsoft.Win32.Registry.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/SOS.NETCore.dll": {
+ "assemblyVersion": "1.0.0.0",
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.AppContext.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Buffers.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Collections.Concurrent.dll": {
+ "assemblyVersion": "4.0.14.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Collections.Immutable.dll": {
+ "assemblyVersion": "1.2.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Collections.NonGeneric.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Collections.Specialized.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Collections.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ComponentModel.Annotations.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ComponentModel.DataAnnotations.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ComponentModel.EventBasedAsync.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ComponentModel.Primitives.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ComponentModel.TypeConverter.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ComponentModel.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Configuration.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Console.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Core.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Data.Common.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Data.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.Contracts.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.Debug.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.DiagnosticSource.dll": {
+ "assemblyVersion": "4.0.3.1",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.FileVersionInfo.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.Process.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.StackTrace.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.TextWriterTraceListener.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.Tools.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.TraceSource.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Diagnostics.Tracing.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Drawing.Primitives.dll": {
+ "assemblyVersion": "4.2.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Drawing.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Dynamic.Runtime.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Globalization.Calendars.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Globalization.Extensions.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Globalization.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.Compression.Brotli.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.Compression.FileSystem.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.Compression.ZipFile.dll": {
+ "assemblyVersion": "4.0.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.Compression.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.FileSystem.AccessControl.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.FileSystem.DriveInfo.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.FileSystem.Primitives.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.FileSystem.Watcher.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.FileSystem.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.IsolatedStorage.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.MemoryMappedFiles.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.Pipes.AccessControl.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.Pipes.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.UnmanagedMemoryStream.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.IO.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Linq.Expressions.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Linq.Parallel.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Linq.Queryable.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Linq.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Memory.dll": {
+ "assemblyVersion": "4.1.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Http.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.HttpListener.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Mail.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.NameResolution.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.NetworkInformation.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Ping.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Primitives.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Requests.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Security.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.ServicePoint.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.Sockets.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.WebClient.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.WebHeaderCollection.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.WebProxy.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.WebSockets.Client.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.WebSockets.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Net.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Numerics.Vectors.dll": {
+ "assemblyVersion": "4.1.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Numerics.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ObjectModel.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Private.DataContractSerialization.dll": {
+ "assemblyVersion": "4.1.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Private.Uri.dll": {
+ "assemblyVersion": "4.0.5.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Private.Xml.Linq.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Private.Xml.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.DispatchProxy.dll": {
+ "assemblyVersion": "4.0.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.Emit.ILGeneration.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.Emit.Lightweight.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.Emit.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.Extensions.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.Metadata.dll": {
+ "assemblyVersion": "1.4.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.Primitives.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.TypeExtensions.dll": {
+ "assemblyVersion": "4.1.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Reflection.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Resources.Reader.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Resources.ResourceManager.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Resources.Writer.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.CompilerServices.VisualC.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Extensions.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Handles.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.InteropServices.RuntimeInformation.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.InteropServices.WindowsRuntime.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.InteropServices.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Loader.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Numerics.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Serialization.Formatters.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Serialization.Json.dll": {
+ "assemblyVersion": "4.0.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Serialization.Primitives.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Serialization.Xml.dll": {
+ "assemblyVersion": "4.1.4.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.Serialization.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Runtime.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.AccessControl.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Claims.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.Algorithms.dll": {
+ "assemblyVersion": "4.3.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.Cng.dll": {
+ "assemblyVersion": "4.3.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.Csp.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.Encoding.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.OpenSsl.dll": {
+ "assemblyVersion": "4.1.1.1",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.Primitives.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Cryptography.X509Certificates.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Principal.Windows.dll": {
+ "assemblyVersion": "4.1.1.1",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.Principal.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.SecureString.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Security.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ServiceModel.Web.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ServiceProcess.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Text.Encoding.Extensions.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Text.Encoding.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Text.RegularExpressions.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Overlapped.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Tasks.Dataflow.dll": {
+ "assemblyVersion": "4.6.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Tasks.Extensions.dll": {
+ "assemblyVersion": "4.3.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Tasks.Parallel.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Tasks.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Thread.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.ThreadPool.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.Timer.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Threading.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Transactions.Local.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Transactions.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.ValueTuple.dll": {
+ "assemblyVersion": "4.0.3.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Web.HttpUtility.dll": {
+ "assemblyVersion": "4.0.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Web.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Windows.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.Linq.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.ReaderWriter.dll": {
+ "assemblyVersion": "4.2.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.Serialization.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.XDocument.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.XPath.XDocument.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.XPath.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.XmlDocument.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.XmlSerializer.dll": {
+ "assemblyVersion": "4.1.1.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.Xml.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/System.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/WindowsBase.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/mscorlib.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/lib/netcoreapp2.1/netstandard.dll": {
+ "assemblyVersion": "2.0.0.0",
+ "fileVersion": "4.6.27818.1"
+ }
+ },
+ "native": {
+ "runtimes/win-x86/native/API-MS-Win-core-xstate-l2-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/Microsoft.DiaSymReader.Native.x86.dll": {
+ "fileVersion": "14.12.25830.2"
+ },
+ "runtimes/win-x86/native/System.Private.CoreLib.dll": {
+ "assemblyVersion": "4.0.0.0",
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-console-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-datetime-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-debug-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-errorhandling-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-file-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-file-l1-2-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-file-l2-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-handle-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-heap-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-interlocked-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-libraryloader-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-localization-l1-2-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-memory-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-namedpipe-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-processenvironment-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-processthreads-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-processthreads-l1-1-1.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-profile-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-rtlsupport-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-string-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-synch-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-synch-l1-2-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-sysinfo-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-timezone-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-core-util-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-conio-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-convert-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-environment-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-filesystem-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-heap-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-locale-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-math-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-multibyte-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-private-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-process-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-runtime-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-stdio-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-string-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-time-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/api-ms-win-crt-utility-l1-1-0.dll": {
+ "fileVersion": "10.0.17134.12"
+ },
+ "runtimes/win-x86/native/clrcompression.dll": {
+ "fileVersion": "4.6.27818.1"
+ },
+ "runtimes/win-x86/native/clretwrc.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/clrjit.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/coreclr.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/dbgshim.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/mscordaccore.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/mscordaccore_x86_x86_4.6.27817.01.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/mscordbi.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/mscorrc.debug.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/mscorrc.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/sos.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/sos_x86_x86_4.6.27817.01.dll": {
+ "fileVersion": "4.6.27817.1"
+ },
+ "runtimes/win-x86/native/ucrtbase.dll": {
+ "fileVersion": "10.0.17134.12"
+ }
+ }
+ },
+ "runtime.win-x86.Microsoft.NETCore.DotNetAppHost/2.1.12": {
+ "native": {
+ "runtimes/win-x86/native/apphost.exe": {
+ "fileVersion": "0.0.0.0"
+ }
+ }
+ },
+ "runtime.win-x86.Microsoft.NETCore.DotNetHostPolicy/2.1.12": {
+ "dependencies": {
+ "Microsoft.NETCore.DotNetHostResolver": "2.1.12"
+ },
+ "native": {
+ "runtimes/win-x86/native/hostpolicy.dll": {
+ "fileVersion": "2.1.27818.1"
+ }
+ }
+ },
+ "runtime.win-x86.Microsoft.NETCore.DotNetHostResolver/2.1.12": {
+ "dependencies": {
+ "Microsoft.NETCore.DotNetAppHost": "2.1.12"
+ },
+ "native": {
+ "runtimes/win-x86/native/hostfxr.dll": {
+ "fileVersion": "2.1.27818.1"
+ }
+ }
+ },
+ "System.AppContext/4.3.0": {
+ "dependencies": {
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Buffers/4.3.0": {
+ "dependencies": {
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Diagnostics.Tracing": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Threading": "4.3.0"
+ }
+ },
+ "System.Collections/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Collections.Concurrent/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Diagnostics.Tracing": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.Collections.Immutable/1.5.0": {},
+ "System.ComponentModel.Annotations/4.5.0": {},
+ "System.Console/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.IO": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Text.Encoding": "4.3.0"
+ }
+ },
+ "System.Diagnostics.Debug/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Diagnostics.FileVersionInfo/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.IO.FileSystem": "4.3.0",
+ "System.IO.FileSystem.Primitives": "4.3.0",
+ "System.Reflection.Metadata": "1.6.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0"
+ }
+ },
+ "System.Diagnostics.StackTrace/4.3.0": {
+ "dependencies": {
+ "System.IO.FileSystem": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Metadata": "1.6.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Diagnostics.Tools/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Diagnostics.Tracing/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Dynamic.Runtime/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Linq": "4.3.0",
+ "System.Linq.Expressions": "4.3.0",
+ "System.ObjectModel": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Emit": "4.3.0",
+ "System.Reflection.Emit.ILGeneration": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Reflection.TypeExtensions": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Threading": "4.3.0"
+ }
+ },
+ "System.Globalization/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Globalization.Calendars/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Globalization": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.IO/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.IO.Compression/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.Buffers": "4.3.0",
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Threading.Tasks": "4.3.0",
+ "runtime.native.System": "4.3.0",
+ "runtime.native.System.IO.Compression": "4.3.0"
+ }
+ },
+ "System.IO.FileSystem/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.IO": "4.3.0",
+ "System.IO.FileSystem.Primitives": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.IO.FileSystem.Primitives/4.3.0": {
+ "dependencies": {
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Linq/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0"
+ }
+ },
+ "System.Linq.Expressions/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Linq": "4.3.0",
+ "System.ObjectModel": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Emit": "4.3.0",
+ "System.Reflection.Emit.ILGeneration": "4.3.0",
+ "System.Reflection.Emit.Lightweight": "4.3.0",
+ "System.Reflection.Extensions": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Reflection.TypeExtensions": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Threading": "4.3.0"
+ }
+ },
+ "System.Memory/4.5.1": {},
+ "System.ObjectModel/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Threading": "4.3.0"
+ }
+ },
+ "System.Reflection/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.IO": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Reflection.Emit/4.3.0": {
+ "dependencies": {
+ "System.IO": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Emit.ILGeneration": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Reflection.Emit.ILGeneration/4.3.0": {
+ "dependencies": {
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Reflection.Emit.Lightweight/4.3.0": {
+ "dependencies": {
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Emit.ILGeneration": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Reflection.Extensions/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Reflection": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Reflection.Metadata/1.6.0": {},
+ "System.Reflection.Primitives/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Reflection.TypeExtensions/4.3.0": {
+ "dependencies": {
+ "System.Reflection": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Resources.ResourceManager/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Globalization": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Runtime/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0"
+ }
+ },
+ "System.Runtime.CompilerServices.Unsafe/4.5.1": {
+ "runtime": {
+ "lib/netcoreapp2.0/System.Runtime.CompilerServices.Unsafe.dll": {
+ "assemblyVersion": "4.0.4.0",
+ "fileVersion": "0.0.0.0"
+ }
+ }
+ },
+ "System.Runtime.Extensions/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Runtime.Handles/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Runtime.InteropServices/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Reflection": "4.3.0",
+ "System.Reflection.Primitives": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Handles": "4.3.0"
+ }
+ },
+ "System.Runtime.Numerics/4.3.0": {
+ "dependencies": {
+ "System.Globalization": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.Algorithms/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.Collections": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Runtime.Numerics": "4.3.0",
+ "System.Security.Cryptography.Encoding": "4.3.0",
+ "System.Security.Cryptography.Primitives": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "runtime.native.System.Security.Cryptography.Apple": "4.3.0",
+ "runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.Cng/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Security.Cryptography.Algorithms": "4.3.0",
+ "System.Security.Cryptography.Encoding": "4.3.0",
+ "System.Security.Cryptography.Primitives": "4.3.0",
+ "System.Text.Encoding": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.Csp/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.IO": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Security.Cryptography.Algorithms": "4.3.0",
+ "System.Security.Cryptography.Encoding": "4.3.0",
+ "System.Security.Cryptography.Primitives": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.Encoding/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.Collections": "4.3.0",
+ "System.Collections.Concurrent": "4.3.0",
+ "System.Linq": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Security.Cryptography.Primitives": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.OpenSsl/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Runtime.Numerics": "4.3.0",
+ "System.Security.Cryptography.Algorithms": "4.3.0",
+ "System.Security.Cryptography.Encoding": "4.3.0",
+ "System.Security.Cryptography.Primitives": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.Primitives/4.3.0": {
+ "dependencies": {
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.Security.Cryptography.X509Certificates/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.Globalization.Calendars": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.IO.FileSystem": "4.3.0",
+ "System.IO.FileSystem.Primitives": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Runtime.Numerics": "4.3.0",
+ "System.Security.Cryptography.Algorithms": "4.3.0",
+ "System.Security.Cryptography.Cng": "4.3.0",
+ "System.Security.Cryptography.Csp": "4.3.0",
+ "System.Security.Cryptography.Encoding": "4.3.0",
+ "System.Security.Cryptography.OpenSsl": "4.3.0",
+ "System.Security.Cryptography.Primitives": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading": "4.3.0",
+ "runtime.native.System": "4.3.0",
+ "runtime.native.System.Net.Http": "4.3.0",
+ "runtime.native.System.Security.Cryptography.OpenSsl": "4.3.0"
+ }
+ },
+ "System.Text.Encoding/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Text.Encoding.CodePages/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "System.Collections": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.Handles": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading": "4.3.0"
+ },
+ "runtime": {
+ "runtimes/win/lib/netstandard1.3/System.Text.Encoding.CodePages.dll": {
+ "assemblyVersion": "4.0.2.0",
+ "fileVersion": "4.6.24702.1"
+ }
+ }
+ },
+ "System.Text.Encoding.Extensions/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0",
+ "System.Text.Encoding": "4.3.0"
+ }
+ },
+ "System.Text.RegularExpressions/4.3.0": {
+ "dependencies": {
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Threading/4.3.0": {
+ "dependencies": {
+ "System.Runtime": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.Threading.Tasks/4.3.0": {
+ "dependencies": {
+ "Microsoft.NETCore.Platforms": "2.1.5",
+ "Microsoft.NETCore.Targets": "2.0.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Threading.Tasks.Extensions/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.Threading.Tasks.Parallel/4.3.0": {
+ "dependencies": {
+ "System.Collections.Concurrent": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Diagnostics.Tracing": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Threading.Tasks": "4.3.0"
+ }
+ },
+ "System.Threading.Thread/4.3.0": {
+ "dependencies": {
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.ValueTuple/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0"
+ }
+ },
+ "System.Xml.ReaderWriter/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.IO.FileSystem": "4.3.0",
+ "System.IO.FileSystem.Primitives": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Runtime.InteropServices": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Text.Encoding.Extensions": "4.3.0",
+ "System.Text.RegularExpressions": "4.3.0",
+ "System.Threading.Tasks": "4.3.0",
+ "System.Threading.Tasks.Extensions": "4.3.0"
+ }
+ },
+ "System.Xml.XDocument/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Diagnostics.Tools": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Reflection": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Xml.ReaderWriter": "4.3.0"
+ }
+ },
+ "System.Xml.XmlDocument/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Text.Encoding": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Xml.ReaderWriter": "4.3.0"
+ }
+ },
+ "System.Xml.XPath/4.3.0": {
+ "dependencies": {
+ "System.Collections": "4.3.0",
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Globalization": "4.3.0",
+ "System.IO": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Xml.ReaderWriter": "4.3.0"
+ }
+ },
+ "System.Xml.XPath.XDocument/4.3.0": {
+ "dependencies": {
+ "System.Diagnostics.Debug": "4.3.0",
+ "System.Linq": "4.3.0",
+ "System.Resources.ResourceManager": "4.3.0",
+ "System.Runtime": "4.3.0",
+ "System.Runtime.Extensions": "4.3.0",
+ "System.Threading": "4.3.0",
+ "System.Xml.ReaderWriter": "4.3.0",
+ "System.Xml.XDocument": "4.3.0",
+ "System.Xml.XPath": "4.3.0"
+ }
+ },
+ "Capnp.Net.Runtime/1.0.0": {
+ "dependencies": {
+ "Microsoft.Extensions.Logging": "2.2.0"
+ },
+ "runtime": {
+ "Capnp.Net.Runtime.dll": {}
+ }
+ }
+ }
+ },
+ "libraries": {
+ "capnpc-csharp/1.0.0": {
+ "type": "project",
+ "serviceable": false,
+ "sha512": ""
+ },
+ "Microsoft.CodeAnalysis.Analyzers/2.6.1": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-VsT6gg2SPeToP8SK7PEcsH6Ftryb7aOqnXh9xg11zBeov05+63gP3k/TvrR+v85XIa8Nn0y3+qNl4M+qzNLBfw==",
+ "path": "microsoft.codeanalysis.analyzers/2.6.1",
+ "hashPath": "microsoft.codeanalysis.analyzers.2.6.1.nupkg.sha512"
+ },
+ "Microsoft.CodeAnalysis.Common/2.10.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-w57ebW3QIRFPoFFX6GCa6eF2FmuHYaWEJ/sMMHq+PBnHB51dEzLIoAQft1Byqe5nrSo4UUV6v4tad8fkTrKl8w==",
+ "path": "microsoft.codeanalysis.common/2.10.0",
+ "hashPath": "microsoft.codeanalysis.common.2.10.0.nupkg.sha512"
+ },
+ "Microsoft.CodeAnalysis.CSharp/2.10.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-bTr6j4V7G4ZPhRDUdowdtbEvXsQA4w1TYfOtXiYdv8TF7STl9ShOKtlSVzAusmeEWsZksJm9D1VSxt6XIyNB0w==",
+ "path": "microsoft.codeanalysis.csharp/2.10.0",
+ "hashPath": "microsoft.codeanalysis.csharp.2.10.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Configuration/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-nOP8R1mVb/6mZtm2qgAJXn/LFm/2kMjHDAg/QJLFG6CuWYJtaD3p1BwQhufBVvRzL9ceJ/xF0SQ0qsI2GkDQAA==",
+ "path": "microsoft.extensions.configuration/2.2.0",
+ "hashPath": "microsoft.extensions.configuration.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Configuration.Abstractions/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-65MrmXCziWaQFrI0UHkQbesrX5wTwf9XPjY5yFm/VkgJKFJ5gqvXRoXjIZcf2wLi5ZlwGz/oMYfyURVCWbM5iw==",
+ "path": "microsoft.extensions.configuration.abstractions/2.2.0",
+ "hashPath": "microsoft.extensions.configuration.abstractions.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Configuration.Binder/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-vJ9xvOZCnUAIHcGC3SU35r3HKmHTVIeHzo6u/qzlHAqD8m6xv92MLin4oJntTvkpKxVX3vI1GFFkIQtU3AdlsQ==",
+ "path": "microsoft.extensions.configuration.binder/2.2.0",
+ "hashPath": "microsoft.extensions.configuration.binder.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.DependencyInjection.Abstractions/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-f9hstgjVmr6rmrfGSpfsVOl2irKAgr1QjrSi3FgnS7kulxband50f2brRLwySAQTADPZeTdow0mpSMcoAdadCw==",
+ "path": "microsoft.extensions.dependencyinjection.abstractions/2.2.0",
+ "hashPath": "microsoft.extensions.dependencyinjection.abstractions.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Logging/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-Nxqhadc9FCmFHzU+fz3oc8sFlE6IadViYg8dfUdGzJZ2JUxnCsRghBhhOWdM4B2zSZqEc+0BjliBh/oNdRZuig==",
+ "path": "microsoft.extensions.logging/2.2.0",
+ "hashPath": "microsoft.extensions.logging.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Logging.Abstractions/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-B2WqEox8o+4KUOpL7rZPyh6qYjik8tHi2tN8Z9jZkHzED8ElYgZa/h6K+xliB435SqUcWT290Fr2aa8BtZjn8A==",
+ "path": "microsoft.extensions.logging.abstractions/2.2.0",
+ "hashPath": "microsoft.extensions.logging.abstractions.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Options/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-UpZLNLBpIZ0GTebShui7xXYh6DmBHjWM8NxGxZbdQh/bPZ5e6YswqI+bru6BnEL5eWiOdodsXtEz3FROcgi/qg==",
+ "path": "microsoft.extensions.options/2.2.0",
+ "hashPath": "microsoft.extensions.options.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.Extensions.Primitives/2.2.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-azyQtqbm4fSaDzZHD/J+V6oWMFaf2tWP4WEGIYePLCMw3+b2RQdj9ybgbQyjCshcitQKQ4lEDOZjmSlTTrHxUg==",
+ "path": "microsoft.extensions.primitives/2.2.0",
+ "hashPath": "microsoft.extensions.primitives.2.2.0.nupkg.sha512"
+ },
+ "Microsoft.NETCore.App/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-oVeSsnIqzD0VuS3xoZRA1SAfq/aLscEy12TaeIP5H6FIOBo9Ta1sMkyc7Pj3ZDJz3fsWeYf/4fR5Ft8Y+oqdzg==",
+ "path": "microsoft.netcore.app/2.1.12",
+ "hashPath": "microsoft.netcore.app.2.1.12.nupkg.sha512"
+ },
+ "Microsoft.NETCore.DotNetAppHost/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-bjRuqLIp7JLORwwH5PTZOKIozs68ulLLcSMRcTmOymOqV35PFE+VE6M2SmR6OQsxG0ViIuxM1YwQdYwlIzG3cQ==",
+ "path": "microsoft.netcore.dotnetapphost/2.1.12",
+ "hashPath": "microsoft.netcore.dotnetapphost.2.1.12.nupkg.sha512"
+ },
+ "Microsoft.NETCore.DotNetHostPolicy/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-A1tafTgEtO7yLIst4n7PrZJtqyc25JHEPII5/2tTIqTymaUA8p8wun9SpwX0dTYxcQbQmfK2yp402kuHU3oVcQ==",
+ "path": "microsoft.netcore.dotnethostpolicy/2.1.12",
+ "hashPath": "microsoft.netcore.dotnethostpolicy.2.1.12.nupkg.sha512"
+ },
+ "Microsoft.NETCore.DotNetHostResolver/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-S7trRhPhQ/O+ZapKoKyjmiveC78yUAQ1usE3qsVT2W9NfI1Hk04aIwDwmio9GWNqUljXzCbK+B7h9CQe5GPJMQ==",
+ "path": "microsoft.netcore.dotnethostresolver/2.1.12",
+ "hashPath": "microsoft.netcore.dotnethostresolver.2.1.12.nupkg.sha512"
+ },
+ "Microsoft.NETCore.Platforms/2.1.5": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-FW1dYOftgUODWh91w97B7fJL9oaderZzbIOGNRe3FS9Yl40yaMz+cHWdQ+X9uE9agCmLzuCx/Yyxt8QSnooHsA==",
+ "path": "microsoft.netcore.platforms/2.1.5",
+ "hashPath": "microsoft.netcore.platforms.2.1.5.nupkg.sha512"
+ },
+ "Microsoft.NETCore.Targets/2.0.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-odP/tJj1z6GylFpNo7pMtbd/xQgTC3Ex2If63dRTL38bBNMwsBnJ+RceUIyHdRBC0oik/3NehYT+oECwBhIM3Q==",
+ "path": "microsoft.netcore.targets/2.0.0",
+ "hashPath": "microsoft.netcore.targets.2.0.0.nupkg.sha512"
+ },
+ "NETStandard.Library/2.0.3": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-st47PosZSHrjECdjeIzZQbzivYBJFv6P2nv4cj2ypdI204DO+vZ7l5raGMiX4eXMJ53RfOIg+/s4DHVZ54Nu2A==",
+ "path": "netstandard.library/2.0.3",
+ "hashPath": "netstandard.library.2.0.3.nupkg.sha512"
+ },
+ "runtime.debian.8-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-HdSSp5MnJSsg08KMfZThpuLPJpPwE5hBXvHwoKWosyHHfe8Mh5WKT0ylEOf6yNzX6Ngjxe4Whkafh5q7Ymac4Q==",
+ "path": "runtime.debian.8-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.debian.8-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.fedora.23-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-+yH1a49wJMy8Zt4yx5RhJrxO/DBDByAiCzNwiETI+1S4mPdCu0OY4djdciC7Vssk0l22wQaDLrXxXkp+3+7bVA==",
+ "path": "runtime.fedora.23-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.fedora.23-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.fedora.24-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-c3YNH1GQJbfIPJeCnr4avseugSqPrxwIqzthYyZDN6EuOyNOzq+y2KSUfRcXauya1sF4foESTgwM5e1A8arAKw==",
+ "path": "runtime.fedora.24-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.fedora.24-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.native.System/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-c/qWt2LieNZIj1jGnVNsE2Kl23Ya2aSTBuXMD6V7k9KWr6l16Tqdwq+hJScEpWER9753NWC8h96PaVNY5Ld7Jw==",
+ "path": "runtime.native.system/4.3.0",
+ "hashPath": "runtime.native.system.4.3.0.nupkg.sha512"
+ },
+ "runtime.native.System.IO.Compression/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-INBPonS5QPEgn7naufQFXJEp3zX6L4bwHgJ/ZH78aBTpeNfQMtf7C6VrAFhlq2xxWBveIOWyFzQjJ8XzHMhdOQ==",
+ "path": "runtime.native.system.io.compression/4.3.0",
+ "hashPath": "runtime.native.system.io.compression.4.3.0.nupkg.sha512"
+ },
+ "runtime.native.System.Net.Http/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-ZVuZJqnnegJhd2k/PtAbbIcZ3aZeITq3sj06oKfMBSfphW3HDmk/t4ObvbOk/JA/swGR0LNqMksAh/f7gpTROg==",
+ "path": "runtime.native.system.net.http/4.3.0",
+ "hashPath": "runtime.native.system.net.http.4.3.0.nupkg.sha512"
+ },
+ "runtime.native.System.Security.Cryptography.Apple/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-DloMk88juo0OuOWr56QG7MNchmafTLYWvABy36izkrLI5VledI0rq28KGs1i9wbpeT9NPQrx/wTf8U2vazqQ3Q==",
+ "path": "runtime.native.system.security.cryptography.apple/4.3.0",
+ "hashPath": "runtime.native.system.security.cryptography.apple.4.3.0.nupkg.sha512"
+ },
+ "runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-NS1U+700m4KFRHR5o4vo9DSlTmlCKu/u7dtE5sUHVIPB+xpXxYQvgBgA6wEIeCz6Yfn0Z52/72WYsToCEPJnrw==",
+ "path": "runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.opensuse.13.2-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-zWLOQ77Y4FV/6Vw2g+FYzprbQX5/xKvjoCLe4L9159Aw1bSboQoJ1KRZFNdexDooWRAIsLSdE0ZokkrVkwN8Yw==",
+ "path": "runtime.opensuse.13.2-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.opensuse.13.2-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.opensuse.42.1-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-KeLz4HClKf+nFS7p/6Fi/CqyLXh81FpiGzcmuS8DGi9lUqSnZ6Es23/gv2O+1XVGfrbNmviF7CckBpavkBoIFQ==",
+ "path": "runtime.opensuse.42.1-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.opensuse.42.1-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.osx.10.10-x64.runtime.native.System.Security.Cryptography.Apple/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-kVXCuMTrTlxq4XOOMAysuNwsXWpYeboGddNGpIgNSZmv1b6r/s/DPk0fYMB7Q5Qo4bY68o48jt4T4y5BVecbCQ==",
+ "path": "runtime.osx.10.10-x64.runtime.native.system.security.cryptography.apple/4.3.0",
+ "hashPath": "runtime.osx.10.10-x64.runtime.native.system.security.cryptography.apple.4.3.0.nupkg.sha512"
+ },
+ "runtime.osx.10.10-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-/p8IQT2brFMDa7BHMH71LV+w5Tb3OxoLHxhn6+MGqN5xeqhM2HRHmj+7xQGJnaRn73d7ZTvp6yRCFMvolws4wA==",
+ "path": "runtime.osx.10.10-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.osx.10.10-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.rhel.7-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-T5NvFgmHX0WH4c7lP72krsnk+IJI10vJf2j2twGE+5QBRA4RyRAgD+ZjEgdmpLOjW4B+nZGaadewTCUcR899OQ==",
+ "path": "runtime.rhel.7-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.rhel.7-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.ubuntu.14.04-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-JGc0pAWRE8lB4Ucygk2pYSKbUPLlAIq6Bczf5/WF2D/VKJEPtYlVUMxk8fbl1zRfTWzSHi+VcFZlaPlWiNxeKg==",
+ "path": "runtime.ubuntu.14.04-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.ubuntu.14.04-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.ubuntu.16.04-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-YWzJvhiC+iLWI/IfpPQUIBhYnAHUFQFRDqR7VDNmPj0b3rjW7dArFqKysZ9v0iSBs9Ih4v9GasLpYCSUwADMQQ==",
+ "path": "runtime.ubuntu.16.04-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.ubuntu.16.04-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.ubuntu.16.10-x64.runtime.native.System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-1uVTITQP8/cI6YoO6FqfW1pzP0k2TnDZ3TFD88Bu/9H7ZuTsMY9xmadbGpwPu8w8swcd1ifZJsjD9hF9O6C/tg==",
+ "path": "runtime.ubuntu.16.10-x64.runtime.native.system.security.cryptography.openssl/4.3.0",
+ "hashPath": "runtime.ubuntu.16.10-x64.runtime.native.system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "runtime.win-x86.Microsoft.NETCore.App/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-1cIhPLl6boIYYyVADtWSVGDgLJtdT5aHo7oeDC9deyv82gx5pMowsAiV9tQ2losj7Xax3rLlbyNh6UOte+PYtg==",
+ "path": "runtime.win-x86.microsoft.netcore.app/2.1.12",
+ "hashPath": "runtime.win-x86.microsoft.netcore.app.2.1.12.nupkg.sha512"
+ },
+ "runtime.win-x86.Microsoft.NETCore.DotNetAppHost/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-pxXLkvYvM6xjZbILQ9NmfZxLgUm5m8F/xKCiCYURZ8D47ErPv5bQMtFsqUwD3pHD2HuFI90zNghjooRL7qYe3A==",
+ "path": "runtime.win-x86.microsoft.netcore.dotnetapphost/2.1.12",
+ "hashPath": "runtime.win-x86.microsoft.netcore.dotnetapphost.2.1.12.nupkg.sha512"
+ },
+ "runtime.win-x86.Microsoft.NETCore.DotNetHostPolicy/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-Z1y5bKz9AQbzSiLqQarlBHLkTHVJp6GIS1q22XwatLyXptEoriJgmeNPcVbzRe6h5A5szGGvF/T0uwa4+LVgRQ==",
+ "path": "runtime.win-x86.microsoft.netcore.dotnethostpolicy/2.1.12",
+ "hashPath": "runtime.win-x86.microsoft.netcore.dotnethostpolicy.2.1.12.nupkg.sha512"
+ },
+ "runtime.win-x86.Microsoft.NETCore.DotNetHostResolver/2.1.12": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-evcWAugroTr6ckGN+s0fYdY3j36+su1KTaCoo9GcTWZ3m9+XzHcyOfndLZRpY/YG4DxFN6DtTNy2ULPDLlr/jw==",
+ "path": "runtime.win-x86.microsoft.netcore.dotnethostresolver/2.1.12",
+ "hashPath": "runtime.win-x86.microsoft.netcore.dotnethostresolver.2.1.12.nupkg.sha512"
+ },
+ "System.AppContext/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-fKC+rmaLfeIzUhagxY17Q9siv/sPrjjKcfNg1Ic8IlQkZLipo8ljcaZQu4VtI4Jqbzjc2VTjzGLF6WmsRXAEgA==",
+ "path": "system.appcontext/4.3.0",
+ "hashPath": "system.appcontext.4.3.0.nupkg.sha512"
+ },
+ "System.Buffers/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-ratu44uTIHgeBeI0dE8DWvmXVBSo4u7ozRZZHOMmK/JPpYyo0dAfgSiHlpiObMQ5lEtEyIXA40sKRYg5J6A8uQ==",
+ "path": "system.buffers/4.3.0",
+ "hashPath": "system.buffers.4.3.0.nupkg.sha512"
+ },
+ "System.Collections/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-3Dcj85/TBdVpL5Zr+gEEBUuFe2icOnLalmEh9hfck1PTYbbyWuZgh4fmm2ysCLTrqLQw6t3TgTyJ+VLp+Qb+Lw==",
+ "path": "system.collections/4.3.0",
+ "hashPath": "system.collections.4.3.0.nupkg.sha512"
+ },
+ "System.Collections.Concurrent/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-ztl69Xp0Y/UXCL+3v3tEU+lIy+bvjKNUmopn1wep/a291pVPK7dxBd6T7WnlQqRog+d1a/hSsgRsmFnIBKTPLQ==",
+ "path": "system.collections.concurrent/4.3.0",
+ "hashPath": "system.collections.concurrent.4.3.0.nupkg.sha512"
+ },
+ "System.Collections.Immutable/1.5.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-EXKiDFsChZW0RjrZ4FYHu9aW6+P4MCgEDCklsVseRfhoO0F+dXeMSsMRAlVXIo06kGJ/zv+2w1a2uc2+kxxSaQ==",
+ "path": "system.collections.immutable/1.5.0",
+ "hashPath": "system.collections.immutable.1.5.0.nupkg.sha512"
+ },
+ "System.ComponentModel.Annotations/4.5.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-UxYQ3FGUOtzJ7LfSdnYSFd7+oEv6M8NgUatatIN2HxNtDdlcvFAf+VIq4Of9cDMJEJC0aSRv/x898RYhB4Yppg==",
+ "path": "system.componentmodel.annotations/4.5.0",
+ "hashPath": "system.componentmodel.annotations.4.5.0.nupkg.sha512"
+ },
+ "System.Console/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-DHDrIxiqk1h03m6khKWV2X8p/uvN79rgSqpilL6uzpmSfxfU5ng8VcPtW4qsDsQDHiTv6IPV9TmD5M/vElPNLg==",
+ "path": "system.console/4.3.0",
+ "hashPath": "system.console.4.3.0.nupkg.sha512"
+ },
+ "System.Diagnostics.Debug/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-ZUhUOdqmaG5Jk3Xdb8xi5kIyQYAA4PnTNlHx1mu9ZY3qv4ELIdKbnL/akbGaKi2RnNUWaZsAs31rvzFdewTj2g==",
+ "path": "system.diagnostics.debug/4.3.0",
+ "hashPath": "system.diagnostics.debug.4.3.0.nupkg.sha512"
+ },
+ "System.Diagnostics.FileVersionInfo/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-omCF64wzQ3Q2CeIqkD6lmmxeMZtGHUmzgFMPjfVaOsyqpR66p/JaZzManMw1s33osoAb5gqpncsjie67+yUPHQ==",
+ "path": "system.diagnostics.fileversioninfo/4.3.0",
+ "hashPath": "system.diagnostics.fileversioninfo.4.3.0.nupkg.sha512"
+ },
+ "System.Diagnostics.StackTrace/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-BiHg0vgtd35/DM9jvtaC1eKRpWZxr0gcQd643ABG7GnvSlf5pOkY2uyd42mMOJoOmKvnpNj0F4tuoS1pacTwYw==",
+ "path": "system.diagnostics.stacktrace/4.3.0",
+ "hashPath": "system.diagnostics.stacktrace.4.3.0.nupkg.sha512"
+ },
+ "System.Diagnostics.Tools/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-UUvkJfSYJMM6x527dJg2VyWPSRqIVB0Z7dbjHst1zmwTXz5CcXSYJFWRpuigfbO1Lf7yfZiIaEUesfnl/g5EyA==",
+ "path": "system.diagnostics.tools/4.3.0",
+ "hashPath": "system.diagnostics.tools.4.3.0.nupkg.sha512"
+ },
+ "System.Diagnostics.Tracing/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-rswfv0f/Cqkh78rA5S8eN8Neocz234+emGCtTF3lxPY96F+mmmUen6tbn0glN6PMvlKQb9bPAY5e9u7fgPTkKw==",
+ "path": "system.diagnostics.tracing/4.3.0",
+ "hashPath": "system.diagnostics.tracing.4.3.0.nupkg.sha512"
+ },
+ "System.Dynamic.Runtime/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-SNVi1E/vfWUAs/WYKhE9+qlS6KqK0YVhnlT0HQtr8pMIA8YX3lwy3uPMownDwdYISBdmAF/2holEIldVp85Wag==",
+ "path": "system.dynamic.runtime/4.3.0",
+ "hashPath": "system.dynamic.runtime.4.3.0.nupkg.sha512"
+ },
+ "System.Globalization/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-kYdVd2f2PAdFGblzFswE4hkNANJBKRmsfa2X5LG2AcWE1c7/4t0pYae1L8vfZ5xvE2nK/R9JprtToA61OSHWIg==",
+ "path": "system.globalization/4.3.0",
+ "hashPath": "system.globalization.4.3.0.nupkg.sha512"
+ },
+ "System.Globalization.Calendars/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-GUlBtdOWT4LTV3I+9/PJW+56AnnChTaOqqTLFtdmype/L500M2LIyXgmtd9X2P2VOkmJd5c67H5SaC2QcL1bFA==",
+ "path": "system.globalization.calendars/4.3.0",
+ "hashPath": "system.globalization.calendars.4.3.0.nupkg.sha512"
+ },
+ "System.IO/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-3qjaHvxQPDpSOYICjUoTsmoq5u6QJAFRUITgeT/4gqkF1bajbSmb1kwSxEA8AHlofqgcKJcM8udgieRNhaJ5Cg==",
+ "path": "system.io/4.3.0",
+ "hashPath": "system.io.4.3.0.nupkg.sha512"
+ },
+ "System.IO.Compression/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-YHndyoiV90iu4iKG115ibkhrG+S3jBm8Ap9OwoUAzO5oPDAWcr0SFwQFm0HjM8WkEZWo0zvLTyLmbvTkW1bXgg==",
+ "path": "system.io.compression/4.3.0",
+ "hashPath": "system.io.compression.4.3.0.nupkg.sha512"
+ },
+ "System.IO.FileSystem/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-3wEMARTnuio+ulnvi+hkRNROYwa1kylvYahhcLk4HSoVdl+xxTFVeVlYOfLwrDPImGls0mDqbMhrza8qnWPTdA==",
+ "path": "system.io.filesystem/4.3.0",
+ "hashPath": "system.io.filesystem.4.3.0.nupkg.sha512"
+ },
+ "System.IO.FileSystem.Primitives/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-6QOb2XFLch7bEc4lIcJH49nJN2HV+OC3fHDgsLVsBVBk3Y4hFAnOBGzJ2lUu7CyDDFo9IBWkSsnbkT6IBwwiMw==",
+ "path": "system.io.filesystem.primitives/4.3.0",
+ "hashPath": "system.io.filesystem.primitives.4.3.0.nupkg.sha512"
+ },
+ "System.Linq/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-5DbqIUpsDp0dFftytzuMmc0oeMdQwjcP/EWxsksIz/w1TcFRkZ3yKKz0PqiYFMmEwPSWw+qNVqD7PJ889JzHbw==",
+ "path": "system.linq/4.3.0",
+ "hashPath": "system.linq.4.3.0.nupkg.sha512"
+ },
+ "System.Linq.Expressions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-PGKkrd2khG4CnlyJwxwwaWWiSiWFNBGlgXvJpeO0xCXrZ89ODrQ6tjEWS/kOqZ8GwEOUATtKtzp1eRgmYNfclg==",
+ "path": "system.linq.expressions/4.3.0",
+ "hashPath": "system.linq.expressions.4.3.0.nupkg.sha512"
+ },
+ "System.Memory/4.5.1": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-sDJYJpGtTgx+23Ayu5euxG5mAXWdkDb4+b0rD0Cab0M1oQS9H0HXGPriKcqpXuiJDTV7fTp/d+fMDJmnr6sNvA==",
+ "path": "system.memory/4.5.1",
+ "hashPath": "system.memory.4.5.1.nupkg.sha512"
+ },
+ "System.ObjectModel/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-bdX+80eKv9bN6K4N+d77OankKHGn6CH711a6fcOpMQu2Fckp/Ft4L/kW9WznHpyR0NRAvJutzOMHNNlBGvxQzQ==",
+ "path": "system.objectmodel/4.3.0",
+ "hashPath": "system.objectmodel.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-KMiAFoW7MfJGa9nDFNcfu+FpEdiHpWgTcS2HdMpDvt9saK3y/G4GwprPyzqjFH9NTaGPQeWNHU+iDlDILj96aQ==",
+ "path": "system.reflection/4.3.0",
+ "hashPath": "system.reflection.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection.Emit/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-228FG0jLcIwTVJyz8CLFKueVqQK36ANazUManGaJHkO0icjiIypKW7YLWLIWahyIkdh5M7mV2dJepllLyA1SKg==",
+ "path": "system.reflection.emit/4.3.0",
+ "hashPath": "system.reflection.emit.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection.Emit.ILGeneration/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-59tBslAk9733NXLrUJrwNZEzbMAcu8k344OYo+wfSVygcgZ9lgBdGIzH/nrg3LYhXceynyvTc8t5/GD4Ri0/ng==",
+ "path": "system.reflection.emit.ilgeneration/4.3.0",
+ "hashPath": "system.reflection.emit.ilgeneration.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection.Emit.Lightweight/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-oadVHGSMsTmZsAF864QYN1t1QzZjIcuKU3l2S9cZOwDdDueNTrqq1yRj7koFfIGEnKpt6NjpL3rOzRhs4ryOgA==",
+ "path": "system.reflection.emit.lightweight/4.3.0",
+ "hashPath": "system.reflection.emit.lightweight.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection.Extensions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-rJkrJD3kBI5B712aRu4DpSIiHRtr6QlfZSQsb0hYHrDCZORXCFjQfoipo2LaMUHoT9i1B7j7MnfaEKWDFmFQNQ==",
+ "path": "system.reflection.extensions/4.3.0",
+ "hashPath": "system.reflection.extensions.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection.Metadata/1.6.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-COC1aiAJjCoA5GBF+QKL2uLqEBew4JsCkQmoHKbN3TlOZKa2fKLz5CpiRQKDz0RsAOEGsVKqOD5bomsXq/4STQ==",
+ "path": "system.reflection.metadata/1.6.0",
+ "hashPath": "system.reflection.metadata.1.6.0.nupkg.sha512"
+ },
+ "System.Reflection.Primitives/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-5RXItQz5As4xN2/YUDxdpsEkMhvw3e6aNveFXUn4Hl/udNTCNhnKp8lT9fnc3MhvGKh1baak5CovpuQUXHAlIA==",
+ "path": "system.reflection.primitives/4.3.0",
+ "hashPath": "system.reflection.primitives.4.3.0.nupkg.sha512"
+ },
+ "System.Reflection.TypeExtensions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-7u6ulLcZbyxB5Gq0nMkQttcdBTx57ibzw+4IOXEfR+sXYQoHvjW5LTLyNr8O22UIMrqYbchJQJnos4eooYzYJA==",
+ "path": "system.reflection.typeextensions/4.3.0",
+ "hashPath": "system.reflection.typeextensions.4.3.0.nupkg.sha512"
+ },
+ "System.Resources.ResourceManager/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-/zrcPkkWdZmI4F92gL/TPumP98AVDu/Wxr3CSJGQQ+XN6wbRZcyfSKVoPo17ilb3iOr0cCRqJInGwNMolqhS8A==",
+ "path": "system.resources.resourcemanager/4.3.0",
+ "hashPath": "system.resources.resourcemanager.4.3.0.nupkg.sha512"
+ },
+ "System.Runtime/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-JufQi0vPQ0xGnAczR13AUFglDyVYt4Kqnz1AZaiKZ5+GICq0/1MH/mO/eAJHt/mHW1zjKBJd7kV26SrxddAhiw==",
+ "path": "system.runtime/4.3.0",
+ "hashPath": "system.runtime.4.3.0.nupkg.sha512"
+ },
+ "System.Runtime.CompilerServices.Unsafe/4.5.1": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-Zh8t8oqolRaFa9vmOZfdQm/qKejdqz0J9kr7o2Fu0vPeoH3BL1EOXipKWwkWtLT1JPzjByrF19fGuFlNbmPpiw==",
+ "path": "system.runtime.compilerservices.unsafe/4.5.1",
+ "hashPath": "system.runtime.compilerservices.unsafe.4.5.1.nupkg.sha512"
+ },
+ "System.Runtime.Extensions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-guW0uK0fn5fcJJ1tJVXYd7/1h5F+pea1r7FLSOz/f8vPEqbR2ZAknuRDvTQ8PzAilDveOxNjSfr0CHfIQfFk8g==",
+ "path": "system.runtime.extensions/4.3.0",
+ "hashPath": "system.runtime.extensions.4.3.0.nupkg.sha512"
+ },
+ "System.Runtime.Handles/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-OKiSUN7DmTWeYb3l51A7EYaeNMnvxwE249YtZz7yooT4gOZhmTjIn48KgSsw2k2lYdLgTKNJw/ZIfSElwDRVgg==",
+ "path": "system.runtime.handles/4.3.0",
+ "hashPath": "system.runtime.handles.4.3.0.nupkg.sha512"
+ },
+ "System.Runtime.InteropServices/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-uv1ynXqiMK8mp1GM3jDqPCFN66eJ5w5XNomaK2XD+TuCroNTLFGeZ+WCmBMcBDyTFKou3P6cR6J/QsaqDp7fGQ==",
+ "path": "system.runtime.interopservices/4.3.0",
+ "hashPath": "system.runtime.interopservices.4.3.0.nupkg.sha512"
+ },
+ "System.Runtime.Numerics/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-yMH+MfdzHjy17l2KESnPiF2dwq7T+xLnSJar7slyimAkUh/gTrS9/UQOtv7xarskJ2/XDSNvfLGOBQPjL7PaHQ==",
+ "path": "system.runtime.numerics/4.3.0",
+ "hashPath": "system.runtime.numerics.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.Algorithms/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-W1kd2Y8mYSCgc3ULTAZ0hOP2dSdG5YauTb1089T0/kRcN2MpSAW1izOFROrJgxSlMn3ArsgHXagigyi+ibhevg==",
+ "path": "system.security.cryptography.algorithms/4.3.0",
+ "hashPath": "system.security.cryptography.algorithms.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.Cng/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-03idZOqFlsKRL4W+LuCpJ6dBYDUWReug6lZjBa3uJWnk5sPCUXckocevTaUA8iT/MFSrY/2HXkOt753xQ/cf8g==",
+ "path": "system.security.cryptography.cng/4.3.0",
+ "hashPath": "system.security.cryptography.cng.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.Csp/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-X4s/FCkEUnRGnwR3aSfVIkldBmtURMhmexALNTwpjklzxWU7yjMk7GHLKOZTNkgnWnE0q7+BCf9N2LVRWxewaA==",
+ "path": "system.security.cryptography.csp/4.3.0",
+ "hashPath": "system.security.cryptography.csp.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.Encoding/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-1DEWjZZly9ae9C79vFwqaO5kaOlI5q+3/55ohmq/7dpDyDfc8lYe7YVxJUZ5MF/NtbkRjwFRo14yM4OEo9EmDw==",
+ "path": "system.security.cryptography.encoding/4.3.0",
+ "hashPath": "system.security.cryptography.encoding.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.OpenSsl/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-vOYy7Jv9KsG3ld2hLt0GoERd82SZi4BelrbXLwI9yFBYX7kpbvUCWYo4eyevk47cuJXZ9ZLVAryANcc7iY71aA==",
+ "path": "system.security.cryptography.openssl/4.3.0",
+ "hashPath": "system.security.cryptography.openssl.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.Primitives/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-7bDIyVFNL/xKeFHjhobUAQqSpJq9YTOpbEs6mR233Et01STBMXNAc/V+BM6dwYGc95gVh/Zf+iVXWzj3mE8DWg==",
+ "path": "system.security.cryptography.primitives/4.3.0",
+ "hashPath": "system.security.cryptography.primitives.4.3.0.nupkg.sha512"
+ },
+ "System.Security.Cryptography.X509Certificates/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-t2Tmu6Y2NtJ2um0RtcuhP7ZdNNxXEgUm2JeoA/0NvlMjAhKCnM1NX07TDl3244mVp3QU6LPEhT3HTtH1uF7IYw==",
+ "path": "system.security.cryptography.x509certificates/4.3.0",
+ "hashPath": "system.security.cryptography.x509certificates.4.3.0.nupkg.sha512"
+ },
+ "System.Text.Encoding/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-BiIg+KWaSDOITze6jGQynxg64naAPtqGHBwDrLaCtixsa5bKiR8dpPOHA7ge3C0JJQizJE+sfkz1wV+BAKAYZw==",
+ "path": "system.text.encoding/4.3.0",
+ "hashPath": "system.text.encoding.4.3.0.nupkg.sha512"
+ },
+ "System.Text.Encoding.CodePages/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-6ENnyNU7cdmUVYblQ9GzLuJlLs9HWyoSInm+JZyCBHFUTaSQZolLIdGSZWGw5VOhjbFop+u/pU0AbKiHQKheqw==",
+ "path": "system.text.encoding.codepages/4.3.0",
+ "hashPath": "system.text.encoding.codepages.4.3.0.nupkg.sha512"
+ },
+ "System.Text.Encoding.Extensions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-YVMK0Bt/A43RmwizJoZ22ei2nmrhobgeiYwFzC4YAN+nue8RF6djXDMog0UCn+brerQoYVyaS+ghy9P/MUVcmw==",
+ "path": "system.text.encoding.extensions/4.3.0",
+ "hashPath": "system.text.encoding.extensions.4.3.0.nupkg.sha512"
+ },
+ "System.Text.RegularExpressions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-RpT2DA+L660cBt1FssIE9CAGpLFdFPuheB7pLpKpn6ZXNby7jDERe8Ua/Ne2xGiwLVG2JOqziiaVCGDon5sKFA==",
+ "path": "system.text.regularexpressions/4.3.0",
+ "hashPath": "system.text.regularexpressions.4.3.0.nupkg.sha512"
+ },
+ "System.Threading/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-VkUS0kOBcUf3Wwm0TSbrevDDZ6BlM+b/HRiapRFWjM5O0NS0LviG0glKmFK+hhPDd1XFeSdU1GmlLhb2CoVpIw==",
+ "path": "system.threading/4.3.0",
+ "hashPath": "system.threading.4.3.0.nupkg.sha512"
+ },
+ "System.Threading.Tasks/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-LbSxKEdOUhVe8BezB/9uOGGppt+nZf6e1VFyw6v3DN6lqitm0OSn2uXMOdtP0M3W4iMcqcivm2J6UgqiwwnXiA==",
+ "path": "system.threading.tasks/4.3.0",
+ "hashPath": "system.threading.tasks.4.3.0.nupkg.sha512"
+ },
+ "System.Threading.Tasks.Extensions/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-npvJkVKl5rKXrtl1Kkm6OhOUaYGEiF9wFbppFRWSMoApKzt2PiPHT2Bb8a5sAWxprvdOAtvaARS9QYMznEUtug==",
+ "path": "system.threading.tasks.extensions/4.3.0",
+ "hashPath": "system.threading.tasks.extensions.4.3.0.nupkg.sha512"
+ },
+ "System.Threading.Tasks.Parallel/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-cbjBNZHf/vQCfcdhzx7knsiygoCKgxL8mZOeocXZn5gWhCdzHIq6bYNKWX0LAJCWYP7bds4yBK8p06YkP0oa0g==",
+ "path": "system.threading.tasks.parallel/4.3.0",
+ "hashPath": "system.threading.tasks.parallel.4.3.0.nupkg.sha512"
+ },
+ "System.Threading.Thread/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-OHmbT+Zz065NKII/ZHcH9XO1dEuLGI1L2k7uYss+9C1jLxTC9kTZZuzUOyXHayRk+dft9CiDf3I/QZ0t8JKyBQ==",
+ "path": "system.threading.thread/4.3.0",
+ "hashPath": "system.threading.thread.4.3.0.nupkg.sha512"
+ },
+ "System.ValueTuple/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-cNLEvBX3d6MMQRZe3SMFNukVbitDAEpVZO17qa0/2FHxZ7Y7PpFRpr6m2615XYM/tYYYf0B+WyHNujqIw8Luwg==",
+ "path": "system.valuetuple/4.3.0",
+ "hashPath": "system.valuetuple.4.3.0.nupkg.sha512"
+ },
+ "System.Xml.ReaderWriter/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-GrprA+Z0RUXaR4N7/eW71j1rgMnEnEVlgii49GZyAjTH7uliMnrOU3HNFBr6fEDBCJCIdlVNq9hHbaDR621XBA==",
+ "path": "system.xml.readerwriter/4.3.0",
+ "hashPath": "system.xml.readerwriter.4.3.0.nupkg.sha512"
+ },
+ "System.Xml.XDocument/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-5zJ0XDxAIg8iy+t4aMnQAu0MqVbqyvfoUVl1yDV61xdo3Vth45oA2FoY4pPkxYAH5f8ixpmTqXeEIya95x0aCQ==",
+ "path": "system.xml.xdocument/4.3.0",
+ "hashPath": "system.xml.xdocument.4.3.0.nupkg.sha512"
+ },
+ "System.Xml.XmlDocument/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-lJ8AxvkX7GQxpC6GFCeBj8ThYVyQczx2+f/cWHJU8tjS7YfI6Cv6bon70jVEgs2CiFbmmM8b9j1oZVx0dSI2Ww==",
+ "path": "system.xml.xmldocument/4.3.0",
+ "hashPath": "system.xml.xmldocument.4.3.0.nupkg.sha512"
+ },
+ "System.Xml.XPath/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-v1JQ5SETnQusqmS3RwStF7vwQ3L02imIzl++sewmt23VGygix04pEH+FCj1yWb+z4GDzKiljr1W7Wfvrx0YwgA==",
+ "path": "system.xml.xpath/4.3.0",
+ "hashPath": "system.xml.xpath.4.3.0.nupkg.sha512"
+ },
+ "System.Xml.XPath.XDocument/4.3.0": {
+ "type": "package",
+ "serviceable": true,
+ "sha512": "sha512-jw9oHHEIVW53mHY9PgrQa98Xo2IZ0ZjrpdOTmtvk+Rvg4tq7dydmxdNqUvJ5YwjDqhn75mBXWttWjiKhWP53LQ==",
+ "path": "system.xml.xpath.xdocument/4.3.0",
+ "hashPath": "system.xml.xpath.xdocument.4.3.0.nupkg.sha512"
+ },
+ "Capnp.Net.Runtime/1.0.0": {
+ "type": "project",
+ "serviceable": false,
+ "sha512": ""
+ }
+ }
+}
\ No newline at end of file
diff --git a/chocolatey/deploy/capnpc-csharp.runtimeconfig.json b/chocolatey/deploy/capnpc-csharp.runtimeconfig.json
new file mode 100644
index 0000000..153e1cf
--- /dev/null
+++ b/chocolatey/deploy/capnpc-csharp.runtimeconfig.json
@@ -0,0 +1,3 @@
+{
+ "runtimeOptions": {}
+}
\ No newline at end of file
diff --git a/scripts/capnpc-csharp-install.ps1 b/scripts/capnpc-csharp-install.ps1
new file mode 100644
index 0000000..cb04d34
--- /dev/null
+++ b/scripts/capnpc-csharp-install.ps1
@@ -0,0 +1,8 @@
+$id = "capnpc-csharp"
+
+$scriptDir = Split-Path -Parent $MyInvocation.MyCommand.Path
+$installDir = "$scriptDir\..\chocolatey\install"
+
+if (!([Security.Principal.WindowsPrincipal][Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole] "Administrator")) { Start-Process powershell.exe "-NoProfile -ExecutionPolicy Bypass -File `"$PSCommandPath`"" -Verb RunAs; exit }
+
+choco install $id -s $installDir --force
diff --git a/scripts/capnpc-csharp-pack.ps1 b/scripts/capnpc-csharp-pack.ps1
new file mode 100644
index 0000000..e1a064d
--- /dev/null
+++ b/scripts/capnpc-csharp-pack.ps1
@@ -0,0 +1,14 @@
+$id = "capnpc-csharp"
+$version = "1.0.0"
+$scriptDir = Split-Path -Parent $MyInvocation.MyCommand.Path
+$prefix = "$id.$version"
+$chocoDir = "$scriptDir\..\chocolatey"
+$nuspecFile = "$prefix.nuspec"
+$nuspecPath = "$chocoDir\$nuspecFile"
+$deployDir = "$chocoDir\deploy"
+$installDir = "$chocoDir\install"
+$csprojDir = "$scriptDir\..\capnpc-csharp"
+$csprojFile = "capnpc-csharp.csproj"
+
+dotnet publish -c Release -r win-x86 --self-contained -o $deployDir "$csprojDir\$csprojFile"
+choco pack $nuspecPath --outputdirectory $installDir
diff --git a/Capnp.Net.Runtime/Framing.cs b/Capnp.Net.Runtime/Framing.cs
index d9f8b69..4c5e32c 100644
--- a/Capnp.Net.Runtime/Framing.cs
+++ b/Capnp.Net.Runtime/Framing.cs
@@ -21,7 +21,7 @@ namespace Capnp
/// The end of the stream is reached.
/// The stream is closed.
/// An I/O error occurs.
/// Encountered invalid framing data.
/// Too many or too large segments, probably due to invalid framing data.
public static WireFrame ReadSegments(Stream stream)
{
@@ -39,15 +39,28 @@ namespace Capnp
throw new InvalidDataException("Encountered invalid framing data");
}
+ // Cannot have more segments than the traversal limit
+ if (scount >= SecurityOptions.TraversalLimit)
+ {
+ throw new InvalidDataException("Too many segments. Probably invalid data. Try increasing the traversal limit.");
+ }
+
var buffers = new Memory[scount];
for (uint i = 0; i < scount; i++)
{
uint size = reader.ReadUInt32();
+
if (size == 0)
{
throw new EndOfStreamException("Stream closed");
}
+
+ if (size >= SecurityOptions.TraversalLimit)
+ {
+ throw new InvalidDataException("Too large segment. Probably invalid data. Try increasing the traversal limit.");
+ }
+
buffers[i] = new Memory(new ulong[size]);
}
@@ -21,7 +21,7 @@ namespace Capnp
/// The stream is closed.
/// An I/O error occurs.
- /// Encountered invalid framing data.
+ /// Encountered invalid framing data, too many or too large segments
/// Too many or too large segments, probably due to invalid framing data.
public static WireFrame ReadSegments(Stream stream)